import { Annotation } from '../Shared/AnnotationInterfaces';
import { DataSource, LogicalTable } from '../Shared/DataSourceInterfaces';
import { Column, DataTable, DataTableReader, GetSummaryDataOptions, GetUnderlyingDataOptions } from '../Shared/DataTableInterfaces';
import { Filter, FilterOptions, RangeFilterOptions, RelativeDateFilterOptions } from '../Shared/FilterInterfaces';
import { DashboardObjectType, DashboardObjectVisibilityType, EncodingType, FilterUpdateType, ReplaySpeedType, SelectOptions, SelectionUpdateType, SheetType, ZoneVisibilityType } from '../Shared/Namespaces/Tableau';
import { MarkInfo, MarksCollection, SelectionCriteria, TooltipContext } from '../Shared/SelectionInterfaces';
import { Size } from '../Shared/SheetInterfaces';
import { VisualSpecification } from '../Shared/VisualModelInterface';
import { WorksheetFormatting } from '../Shared/WorkbookFormattingInterfaces';
import { EventListenerManager } from './EventInterface';
import { Parameter } from './ParameterInterfaces';
export interface Sheet extends EventListenerManager {
    /**
     * @returns  The name of the sheet.
     */
    readonly name: string;
    /**
     * @returns  The type of the sheet.
     */
    readonly sheetType: SheetType;
    /**
     * Searches for a parameter with the given name.
     *
     * @param parameterName   The name of the parameter to find.
     * @returns               The parameter with the given name, or undefined if it does not exist.
     */
    findParameterAsync(parameterName: string): Promise<Parameter | undefined>;
    /**
     * @returns  Size of the sheet.
     */
    readonly size: Size;
    /**
     * @returns  A collection of all the Tableau parameters that are used in this workbook.
     */
    getParametersAsync(): Promise<Array<Parameter>>;
}
export interface Worksheet extends Sheet {
    /**
     * @returns  The dashboard object to which this worksheet belongs.
     * @category Dashboard Extensions
     */
    readonly parentDashboard: Dashboard;
    /**
     * @returns  The background color of the worksheet.
     * @category Viz Extensions
     */
    readonly backgroundColor: string;
    /**
     * @returns  Worksheet level formatting.
     * @category Viz Extensions
     */
    readonly formatting: WorksheetFormatting;
    /**
     * Applies the list of provided categorical filter values.
     *
     * @param fieldName      The name of the field to filter on.
     * @param values         The list of values to filter on.
     * @param updateType     The update type of this filter (add, all, remove, replace).
     * @param filterOptions  Advanced filter options (isExcludeMode).
     *
     * @returns  The field name that the filter is applied on.
     */
    applyFilterAsync(fieldName: string, values: Array<string>, updateType: FilterUpdateType, filterOptions: FilterOptions): Promise<string>;
    /**
     * Applies a range filter to a quantitative or date field.
     *
     * @param fieldName      The name of the field to filter on
     * @param filterOptions  Filter Options: min, max, nullOption. At least one of of min and max is required.
     * For applying date filters, UTC Date objects are expected (that is, `var min = new Date(Date.UTC(1999, 0, 1))`).
     * @return The field name that the filter is applied on.
     * @since 1.10.0 Errors will now be thrown for invalid fields or values.
     */
    applyRangeFilterAsync(fieldName: string, filterOptions: RangeFilterOptions): Promise<string>;
    /**
     * Resets existing filters on the given field.
     * Categorical filters are reset to "All," and range filters are reset to the full range
     * Relative date filters can not be reset, consider using the applyRelativeDateFilterAsync API.
     *
     * @param fieldName  The name of the field to clear filter on.
     *
     * @returns The field to clear filter on.
     */
    clearFilterAsync(fieldName: string): Promise<string>;
    /**
     * Applies the list of provided hierarchial filter values.
     *
     * @param fieldName      The name of the field to filter on.
     * @param values         The list of values or levels to filter on.
     * @param updateType     The update type of this filter (add, all, remove, replace).
     * @param filterOptions  Advanced filter options (isExcludeMode).
     *
     * @returns  The field name that the filter is applied on.
     * @since 1.10.0 and Tableau 2022.3
     *
     */
    applyHierarchicalFilterAsync(fieldName: string, values: Array<string> | HierarchicalLevels, updateType: FilterUpdateType, options: FilterOptions): Promise<string>;
    /**
     * Applies a relative date filter.
     *
     * @param fieldName The name of the field to filter on.
     * @param options   The relative date filter options (anchorDate, periodType, rangeType, rangeN). When the rangeType is LASTN or NEXTN, the rangeN is required.
     *
     * @returns  The field name that the filter is applied on.
     * @since version 1.9.0 and Tableau 2022.2
     *
     * The following example shows how to apply a relative date filter from a worksheet.
     * ```
     *  worksheet.applyRelativeDateFilterAsync(
     *    'Order Date',
     *    {
     *      anchorDate: new Date(Date.UTC(2022, 4, 13)),
     *      periodType: PeriodType.Years,
     *      rangeType: DateRangeType.LastN,
     *      rangeN: 1,
     *    }
     *  );
     * ```
     */
    applyRelativeDateFilterAsync(fieldName: string, options: RelativeDateFilterOptions): Promise<string>;
    /**
     * Gets the data sources for this worksheet. Note that calling this method might negatively impact performance
     *  and responsiveness of the viz that your extension is added to. The method is not entirely
     *  asynchronous and includes some serial operations.
     *
     * @returns The primary data source and all of the secondary data sources for this worksheet.
     *          By convention the first data source in the array is the primary.
     *
     * The following example shows how you might find a specific data source of a worksheet,
     * using the `getDataSourcesAsync()` method. The example then chains the data source returned in the promise
     * to a call to the `getUnderlyingDataAsync()` method to access the data table.
     * ```
     * worksheet.getDataSourcesAsync().then(datasources => {
     *   dataSource = datasources.find(datasource => datasource.name === "Sample - Superstore");
     *   return dataSource.getUnderlyingDataAsync();
      }).then(dataTable => {
           // process the dataTable...
         });
     *
     * ```
  
     *
     */
    getDataSourcesAsync(): Promise<Array<DataSource>>;
    /**
     * Gets the list of filters on a worksheet. Hierarchical filters are not yet supported
     * @returns A promise that resolves to the collection of filters used in this worksheet.
     *
     *
     */
    getFiltersAsync(): Promise<Array<Filter>>;
    /**
     * Gets the data for the marks which are currently highlighted on the worksheet.
     * If there are no marks currently highlighted, an empty model is returned.
     *
     * @returns The marks which are selected.
     */
    getHighlightedMarksAsync(): Promise<MarksCollection>;
    /**
     * Gets the data for the marks which are currently selected on the worksheet.
     * If there are no marks currently selected, an empty model is returned.
     *
     * @returns The marks that are selected.
     *
     *
     *
     * ```
     * // Call to get the selected marks for the worksheet
     * worksheet.getSelectedMarksAsync().then(function (marks) {
     *   // Get the first DataTable for our selected marks (usually there is just one)
     *   const worksheetData = marks.data[0];
     *
     *   // Map the data into a format for display, etc.
     *
     * });
     * ```
     *
     *
     */
    getSelectedMarksAsync(): Promise<MarksCollection>;
    /**
     * Gets the summary data table for this worksheet.
     * Warning: getSummaryDataAsync can fail with a worksheet with many rows of data and is now deprecated.
     *
     * @param options  Collection of options to change the behavior of the call.
     * @returns        A data table containing the summary data for the worksheet.
     *
     * @deprecated since 1.10.0 Use getSummaryDataReaderAsync to avoid failures with many rows of data.
     *
     * ---
     * Note: The `getSummaryDataAsync` and `getSummaryDataReaderAsync` methods return the data that is currently
     * in the viz, with parameters, calculated fields, and sorting applied. To access full data, that is
     * the underlying data without the additional fields and processing you have added in Tableau, use
     * the {@link Worksheet.getUnderlyingTableDataAsync} and {@link Worksheet.getUnderlyingTableDataReaderAsync} methods.
     * ---
     *
     * The following example shows how to replace unsafe usage of `getSummaryDataAsync` with
     * `getSummaryDataReaderAsync` and `getAllPagesAsync`, assuming you have less than 4,000,000
     * rows of data.
     * </br>
     *```
     * const dataTableReader = await worksheet.getSummaryDataReaderAsync();
     * const dataTable = await dataTableReader.getAllPagesAsync();
     * await dataTableReader.releaseAsync();
     * // ... process data table ...
     *```
     * </br>
     *
     * The following example shows how to replace unsafe usage of `getSummaryDataAsync` with
     * `getSummaryDataReaderAsync` and `getPageAsync` and work with individual
     * pages.
     *
     * </br>
     *
     *```
     * const dataTableReader = await worksheet.getSummaryDataReaderAsync();
     * for (let currentPage = 0; currentPage < dataTableReader.pageCount; currentPage++) {
     *   const dataTablePage = await dataTableReader.getPageAsync(currentPage);
     *   // ... process current page ....
     * }
     * await dataTableReader.releaseAsync();
     *```
     */
    getSummaryDataAsync(options?: GetSummaryDataOptions): Promise<DataTable>;
    /**
     * Gets a summary data table reader for this worksheet.
     * Only one active DataTableReader for summary data is supported.
     *
     * ---
     * Note: The `getSummaryDataAsync` and `getSummaryDataReaderAsync` methods return the data that is currently
     * in the viz, with parameters, calculated fields, and sorting applied. To access full data, that is
     * the underlying data without the additional fields and processing you have added in Tableau, use
     * the {@link Worksheet.getUnderlyingTableDataAsync} and {@link Worksheet.getUnderlyingTableDataReaderAsync} methods.
     * ---
     *
     * @param pageRowCount The number of rows per page. The default and maximum is 10,000 rows.
     * @param options  Collection of options to change the behavior of the reader.
     * @returns        A data table reader to access the summary data for the worksheet.
     *
     * The following example shows the methods to get and use the summary data reader for all rows in a worksheet.
     *```
     * const dataTableReader = await worksheet.getSummaryDataReaderAsync();
     * for (let currentPage = 0; currentPage < dataTableReader.pageCount; currentPage++) {
     *   let dataTablePage = await dataTableReader.getPageAsync(currentPage);
     *   // ... process current page ....
     * }
     * await dataTableReader.releaseAsync();
     *```
     */
    getSummaryDataReaderAsync(pageRowCount?: number, options?: GetSummaryDataOptions): Promise<DataTableReader>;
    /**
     * Gets the columns that are returned with `getSummaryDataAsync`.
     *
     * @returns The array of columns that describe the data in the worksheet.
     * @since 1.5.0
     */
    getSummaryColumnsInfoAsync(): Promise<Array<Column>>;
    /**
     * Gets the underlying data table for this worksheet.
     *
     * @param options  Collection of options to change the behavior of the call.
     * @returns        A data table containing the underlying data for the worksheet.
     *
     *
     * @deprecated Use {@link Worksheet.getUnderlyingTableDataReaderAsync} or {@link Worksheet.getUnderlyingTableDataAsync}.
     */
    getUnderlyingDataAsync(options?: GetUnderlyingDataOptions): Promise<DataTable>;
    /**
     * Gets the underlying logical tables used by the worksheet. The resulting logical tables are determined by the measures in the worksheet.
     * If a worksheet's data source contains multiple logical tables and the worksheet contains only measures from one logical table, this API
     * will return one logical table.
     *
     * @since 1.4.0
     * @returns An array of logical tables corresponding to the measures referenced by the worksheet.
     *
     * ```
     * // Call to get the underlying logical tables used by the worksheet
     * worksheet.getUnderlyingTablesAsync().then(function (logicalTables) {
     *   // Get the first logical table's id
     *   const logicalTableId = logicalTables[0].id;
     *
     *   // Use the above logicalTableId to then get worksheet's underlying data
     *   // by calling worksheet.getUnderlyingTableDataAsync(logicalTableId)
     *
     * });
     * ```
     */
    getUnderlyingTablesAsync(): Promise<Array<LogicalTable>>;
    /**
     * Gets the underlying data table for the given logical table id.
     * Use the `getUnderlyingTablesAsync` method to identify the logical tables.
     *
     * @param logicalTableId logical table id.
     * @param options  Collection of options to change the behavior of the call.
     * @returns        A data table containing the underlying data for the given logical table id
     * @since 1.4.0
     *
     * ---
     * Note: Use the `getUnderlyingTableDataAsync` method to access the full data, that is the underlying
     * data without the parameters, calculated fields, and processing you might have added in Tableau.
     * To access just the data that is currently in the viz, with parameters,
     * calculated fields, and sorting applied, use the {@link Worksheet.getSummaryDataAsync} and
     * {@link Worksheet.getSummaryDataReaderAsync} methods.
     * ---
     *
     * You can use the `getUnderlyingDataOptions.maxRows` property to request the number of rows of data to return.
     * If unspecified (maxRows == '0'), the call to `getUnderlyingTableDataAsync` requests all rows in the logical table.
     * Note that the maximum number of rows returned from the `getUnderlyingTableDataAsync()` method is limited
     * to 10,000 rows. You can use the `DataTable` property, `isTotalRowCountLimited`, to test whether there is
     * more data. A value of true indicates that the calling function requested more rows than the limit (10,000) and the
     * underlying data source contains more rows than can be returned.
     *
     * @since 1.5.0 You can use the `GetUnderlyingDataOptions.includeDataValuesOption` property to optimize performance
     * by restricting the properties included in the returned DataValues.
     *
     * @see getUnderlyingTableDataReaderAsync to read more than 10,000 rows.
     * ```
     * const logicalTables = await worksheet.getUnderlyingTablesAsync();
     * const dataTable = await worksheet.getUnderlyingTableDataAsync(logicalTables[0].id)
     * // process the dataTable...
     * ```
     */
    getUnderlyingTableDataAsync(logicalTableId: string, options?: GetUnderlyingDataOptions): Promise<DataTable>;
    /**
     * Gets a underlying data table reader for the given logical table id.
     * Use the `getUnderlyingTablesAsync` method to identify the logical tables.
     * Only one active DataTableReader per logical table id is supported.
     *
     * ---
     * Note: Use the `getUnderlyingTableDataReaderAsync` method to access the full data, that is
     * the underlying data without the parameters, calculated fields, and processing you might
     * have added in Tableau. To access just the data that is currently in the viz, with parameters,
     * calculated fields, and sorting applied use the {@link Worksheet.getSummaryDataAsync} and
     * {@link Worksheet.getSummaryDataReaderAsync} methods.
     * ---
     *
     * The `getUnderlyingTableDataReaderAsync` method attempts to prepare all the rows of the underlying table to be read as pages.
     * However, there is a limit to the number of rows that can be prepared. The default limit is 1 million rows of data.
     * You can change the default limit with the Tableau Server (Cloud) or Tableau Desktop option: ExtensionsAndEmbeddingReaderRowLimit.
     * If the underlying table has many columns, `getUnderlyingTableDataReaderAsync` can be sped up by only requesting
     * native data values in the GetUnderlyingDataOptions.
     *
     * @param logicalTableId logical table id.
     * @param pageRowCount The number of rows per page. The default and maximum is 10,000 rows.
     * @param options  Collection of options to change the behavior of the reader.
     * @returns        A data table reader to access the underlying data for the given logical table id.
     *
     * The following example shows getting the first page of underlying data.
     * ```
     * // Call to get the underlying logical tables used by the worksheet
     * const underlyingTablesData = await worksheet.getUnderlyingTablesAsync();
     * const logicalTableId = underlyingTablesData[0].id;
     * // Use the above logicalTableId to get the underlying data reader on the active sheet
     * const dataTableReader = await worksheet.getUnderlyingTableDataReaderAsync(logicalTableId);
     * const page = await dataTableReader.getPageAsync(0);
     * // ... process first page of data table ...
     * await dataTableReader.releaseAsync();
     * ```
     */
    getUnderlyingTableDataReaderAsync(logicalTableId: string, pageRowCount?: number, options?: GetUnderlyingDataOptions): Promise<DataTableReader>;
    /**
     * @hidden
     * Selects the marks specified by mark ID using the MarkInfo interface.
     * This is intended to be passed the MarkInfo objects that are received from a DataTable.
     *
     * @param marksInfo   The list of marks for the selection.
     * @param updateType  The type of selection to make: add, remove, or replace.
  
     * @returns           Empty promise that resolves when the selection is complete.
     */
    selectMarksByIDAsync(marksInfo: Array<MarkInfo>, updateType: SelectionUpdateType): Promise<void>;
    /**
     * Selects the marks specified by value using the SelectionCriteria interface.
     * This is intended for manual construction of the desired selections.
     *
     * @param selectionCriteria   A list of criteria for which marks to select.
     * @param updateType          The type of selection to make: add, remove, or replace.
     *
     * @returns                   Empty promise that resolves when the selection is complete.
     * @since 1.10.0 Errors will now be thrown for invalid fields or values.
     *
     * </br>
     *
     * The following example shows how you might call this method using state names as the `SelectionCriteria`.
     * The `SelectionUpdateType` is replace (`tableau.SelectionUpdateType.Replace`), so these values replace
     * the marks that are currently selected.
     * ```
     *    worksheet.selectMarksByValueAsync([{
     *         fieldName: 'State',
     *         value: ['Texas', 'Washington', 'California']
     *     }], tableau.SelectionUpdateType.Replace );
     *
     * ```
     *
     */
    selectMarksByValueAsync(selectionCriteria: Array<SelectionCriteria>, updateType: SelectionUpdateType): Promise<void>;
    /**
     * Clears selected marks in the current worksheet.
     *
     * @return Empty promise that resolves when the selection has been cleared.
     *
     * The following example assumes that you have some marks already selected in the worksheet. After it has run,
     * you should have no marks selected, and you should see the console message.
     *
     * ```
     *    worksheet.clearSelectedMarksAsync().then(function () {
     *        console.log('Your marks selection has been cleared!');
     *    })
     * ```
     */
    clearSelectedMarksAsync(): Promise<void>;
    /**
     * Add an annotation to the specified mark.
     * This is intended to be passed a MarkInfo object received from a DataTable.
     * MarkInfo can be found in the DataTable returned from getSelectedMarksAsync or getHighlightedMarksAsync.
     *
     * @param mark            The mark to annotate.
     * @param annotationText  The text to display in the annotation.
     *
     * @returns Empty promise that resolves when the annotation is complete.
     * @since   1.10.0 and Tableau 2022.4
     *
     * The following example shows how you might call this method using a MarkInfo object.
     *
     * ```
     *    const markCollection = await worksheet.getSelectedMarksAsync();
     *    const markToAnnotate = marksCollection.data[0].marksInfo[0];
     *    await worksheet.annotateMarkAsync(markToAnnotate, 'Manufacturing line #2 shutdown triggered');
     * ```
     *
     */
    annotateMarkAsync(mark: MarkInfo, annotationText: string): Promise<void>;
    /**
     * Retrieves a list of the annotations in the worksheet.
     *
     * @returns           A list annotations in the worksheet.
     * @since 1.10.0 and Tableau 2022.4
     *
     * The following example shows how you might call this method.
     *
     * ```
     *    let annotations = await worksheet.getAnnotationsAsync();
     *    console.log(annotations);
     * ```
     *
     */
    getAnnotationsAsync(): Promise<Array<Annotation>>;
    /**
     * Removes the corresponding annotation from the worksheet it belongs to.
     * This is intended to be passed a Annotation object received from getAnnotationsAsync.
     *
     * @param annotation  The annotation to remove.
     * @returns           Empty promise that resolves when the annotation is removed.
     * @since 1.10.0 and Tableau 2022.4
     *
     * The following example shows how you might call this method using an annotation.
     *
     * ```
     *    for (const annotation of annotations) {
     *      await worksheet.removeAnnotationAsync(annotation);
     *    }
     * ```
     *
     */
    removeAnnotationAsync(annotation: Annotation): Promise<void>;
    /**
     * Returns the visual specification for the worksheet, which can be used to get
     * the mappings from fields to encodings backing the visual within the worksheet
     *
     * @returns Promise containing the VisualSpecification
     * @since 1.11.0 and Tableau 2024.1
     *
     */
    getVisualSpecificationAsync(): Promise<VisualSpecification>;
    /**
     * @hidden
     * Add encoding fields to a marks card of the worksheet
     *
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     * @since 1.13.0 and Tableau 2025.1
     *
     */
    addMarksCardFieldsAsync(marksCardIndex: number, encodingType: EncodingType, columns: Array<Column>, startIndex: number): Promise<void>;
    /**
     * @hidden
     * Move encoding field on a marks card of the worksheet
     *
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     * @since 1.13.0 and Tableau 2025.1
     *
     */
    moveMarksCardFieldAsync(marksCardIndex: number, fromIndex: number, toIndex: number): Promise<void>;
    /**
     * @hidden
     * Add and delete encoding fields to a marks card of the worksheet
     *
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     * @since 1.13.0 and Tableau 2025.1
     *
     */
    spliceMarksCardFieldsAsync(marksCardIndex: number, encodingType: EncodingType, startIndex: number, deleteCount: number, columns: Array<Column>): Promise<void>;
    /**
     * Method to execute hover actions and render tooltip for a given tuple representing a mark in the visualization.
     * If the tooltip parameter is included it will show the tooltip when the mark is hovered over.
     * If null or no tooltip parameter is passed, no tooltip is shown.
     * Hover actions are run by default, but passing false for the allowHoverActions parameter will prevent their execution.
     *
     * The `hoveredTuple` parameter is a tuple id. You can find the tuple id for a row of data by subtracting the index of the row from the total number of rows.
     * For example, if you have 10 rows, and want to know the tuple id associated with the third row, it will be 7 (10 - 3 = 7). The last row of data will always have the tuple id of 1.
     *
     * Passing in an invalid tuple id will not throw and will clear the tooltip.
     * <br/>
     *
     * ```
     * svg.on('mousemove', (mouseEvent) => {
     *  const myHoveredTuple = 10;
     *  tableau.extensions.worksheetContent.worksheet.hoverTupleAsync(myHoveredTuple, { tooltipAnchorPoint: { x: mouseEvent.pageX, y: mouseEvent.pageY } })
     *    .then(() => console.log('Done'))
     *    .catch((error) => console.log('Failed to hover because of: ', error));
     *  });
     * ```
     * @since 1.12.0 and Tableau 2024.2
     * @category Viz Extensions
     * @param hoveredTuple
     * @param tooltip
     * @param allowHoverActions
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     */
    hoverTupleAsync(hoveredTuple: number, tooltip?: TooltipContext | null, allowHoverActions?: boolean): Promise<void>;
    /**
     * Method to modify selection, execute select actions, and render tooltip for a given list of tuples representing a mark or marks in the visualization.
     * If the tooltip parameter is included it will show the tooltip when the mark or marks are selected. If not, no tooltip is shown.
     *
     * The `selectedTuples` parameter is an array of tuple ids. You can find the tuple id for a row of data by subtracting the index of the row from the total number of rows.
     * For example, if you have 10 rows, and want to know the tuple id associated with the third row, it will be 7 (10 - 3 = 7). The last row of data will always have the tuple id of 1.
     *
     * Passing in an invalid tuple id will not throw and will clear the tooltip.
     * <br/>
     *
     * ```
     * svg.on('click', (mouseEvent) => {
     * const myClickedTuples = [10];
     * const ctrlKeyPressed = !!mouseEvent.ctrlKey;
     * const selectOption = ctrlKeyPressed ? tableau.SelectOptions.Toggle : tableau.SelectOptions.Simple;
     *
     * tableau.extensions.worksheetContent.worksheet.selectTuplesAsync(myClickedTuples, selectOption, { tooltipAnchorPoint: { x: mouseEvent.pageX, y: mouseEvent.pageY } })
     *    .then(() => console.log('Done'))
     *    .catch((error) => console.log('Failed to select because of: ', error));
     * });
     * ```
     * @since 1.12.0 and Tableau 2024.2
     * @category Viz Extensions
     * @param selectOption
     * @param selectedTuples
     * @param tooltip
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     */
    selectTuplesAsync(selectedTuples: Array<number>, selectOption: SelectOptions, tooltip?: TooltipContext): Promise<void>;
    /**
     * Method to get the text of the tooltip that would be displayed for a given tuple id. Currently supported for web only.
     *
     * You can find the tuple id for a row of data by subtracting the index of the row from the total number of rows.
     * For example, if you have 10 rows, and want to know the tuple id associated with the third row, it will be 7 (10 - 3 = 7). The last row of data will always have the tuple id of 1.
     *
     * Passing in an invalid tuple id will not throw.
     * <br/>
     *
     * ```
     * let navigatedTuple = -1;
     * let updateScreenReaderElement = (screenReadertext) => {
     *   // updates an element to be read out by screen readers
     * };
     *
     * let updateNavigatedTuple = (keyboardEvent) => {
     *   switch (keyboardEvent.key) {
     *     case 'ArrowLeft':
     *       navigatedTuple = navigatedTuple - 1;
     *       break;
     *     case 'ArrowRight':
     *       navigatedTuple = navigatedTuple + 1;
     *       break;
     *     default:
     *       break;
     *   }
     *   // do any work to show visual indication of a mark being navigated to
     * };
     *
     * svg.on('keydown', (keyboardEvent) => {
     *   updateNavigatedTuple(keyboardEvent);
     *   tableau.extensions.worksheetContent.worksheet
     *     .getTooltipTextAsync(navigatedTuple)
     *     .then((response) => {
     *       console.log(response.result);
     *       updateScreenReaderElement(response.result);
     *     })
     *     .catch((error) => console.log('Failed to get tooltip text because of: ', error));
     * });
     * ```
     * @since 1.12.0 and Tableau 2024.2
     * @category Viz Extensions
     * @param tupleId
     * @returns Returns promise that resolves to a string describing the tooltip text for a given tuple id and rejects on error
     */
    getTooltipTextAsync(tupleId: number): Promise<String>;
    /**
     * Notifies the scene of a desire to leave mark-level keyboard navigation and return to scene-level keyboard navigation.
     * Used when implementing [keyboard navigation](https://www.w3.org/TR/UNDERSTANDING-WCAG20/keyboard-operation.html) within a visualization, an integral part of building accessibility into a visualization.
     * Currently supported for the web only.
     * <br/>
     *
     * ```
     * svg.on('keyup', (keyboardEvent) => {
     *   if (keyboardEvent.key == "Escape") {
     *     tableau.extensions.worksheetContent.worksheet
     *       .leaveMarkNavigationAsync()
     *       .then(() => console.log('Done'))
     *       .catch((error) => console.log('Failed to leave mark-level keyboard navigation because of: ', error));
     *   }
     * });
     * ```
     * @since 1.12.0 and Tableau 2024.2
     * @category Viz Extensions
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     */
    leaveMarkNavigationAsync(): Promise<void>;
    /**
     * @hidden
     * Opens the Edit Aliases dialog for a particular field
     *
     * @returns Returns empty promise that resolves when the extension host has successfully been informed of the request and rejects on error
     * @since 1.13.0 and Tableau 2025.1
     *
     */
    editAliasesDialogAsync(fieldName: string): Promise<void>;
}
/**
 * The `Dashboard` interface inherits from the `Sheet` interface.
 * @category Dashboard Extensions
 */
export interface Dashboard extends Sheet {
    /**
     * @returns  The collection of objects contained in the dashboard.
     *
     */
    readonly objects: Array<DashboardObject>;
    /**
     *
     *  This is a helper method and is equivalent to looping
     *  through all of the objects in a dashboard and collecting all of the objects
     *  whose type is `worksheet`. You can use this property to iterate
     *  through all of the worksheets in the dashboard.
     *
     * @returns  The collection of worksheets contained in the dashboard.
     *
     * The following example uses the JavaScript `forEach()` method to traverse
     * the worksheets in the dashboard.
     * <br/>
     *
     * ```
     *    let dashboard = tableau.extensions.dashboardContent.dashboard;
     *    dashboard.worksheets.forEach(function (worksheet) {
     *     // do something with the worksheets..
     *       console.log("The worksheet name is " + worksheet.name)
     *     });
     *
     * ```
     */
    readonly worksheets: Array<Worksheet>;
    /**
     * @returns  The ID of the active object in the dashboard.
     *
     */
    readonly activeDashboardObjectId: number;
    /**
     * @returns  The name of the active dashboard.
     *
     */
    readonly activeDashboardName: string;
    /**
     * Sets the visibility of one or more floating dashboard zones.
     * Throws an error if the zone is invalid
     *
     * @param zoneVisibilityMap    A map of zone ids to the desired state of visibility for that zone.
     * @returns                    Empty promise that resolves when the visibility has been changed.
     * @since 1.1.0
     * @deprecated use setDashboardObjectVisibilityAsync
     *
     * The following example shows how you can update the visibility of multiple (valid, floating) zones in a dashboard
     * <br/>
     *
     * ```
     *   var zoneVisibilityMap = {};
     *   zoneVisibilityMap[10] =  tableau.ZoneVisibilityType.Show;
     *   zoneVisibilityMap[8] =  tableau.ZoneVisibilityType.Hide;
     *   tableau.extensions.dashboardContent.dashboard.setZoneVisibilityAsync(zoneVisibilityMap).then(() => {
     *     console.log("done");
     *   });
     *
     * ```
     * @since 1.4.0 The zoneVisibilityMap can be either an untyped object, or a Map.
     * ```
     *   var zoneVisibilityMap = new Map;
     *   zoneVisibilityMap.set(10, tableau.ZoneVisibilityType.Show);
     *   zoneVisibilityMap.set(8, tableau.ZoneVisibilityType.Hide);
     * ```
     * @since 1.5.0 The zone can be any zone in the dashboard.
     */
    setZoneVisibilityAsync(zoneVisibilityMap: ZoneVisibilityMap): Promise<void>;
    /**
     * Sets the visibility of one or more dashboard objects.
     * Throws an error if the dashboard object is invalid
     *
     * @param dashboardObjectVisibilityMap    A map of dashboard object ids to its desired state of visibility.
     * @returns                               Empty promise that resolves when the visibility has been changed.
     * @since 1.7.0 and Tableau 2021.4
     *
     * The following example shows how you can update the visibility of multiple valid dashboard objects
     * <br/>
     *
     * ```
     *   var dashboardObjectVisibilityMap = new Map();
     *   dashboardObjectVisibilityMap.set(10, tableau.DashboardObjectVisibilityType.Show);
     *   dashboardObjectVisibilityMap.set(8, tableau.DashboardObjectVisibilityType.Hide);
     *   var dashboard = tableau.extensions.dashboardContent.dashboard;
     *   dashboard.setDashboardObjectVisibilityAsync(dashboardObjectVisibilityMap).then(() => {
     *     console.log("done");
     *   });
     *
     * ```
     */
    setDashboardObjectVisibilityAsync(dashboardObjectVisibilityMap: DashboardObjectVisibilityMap): Promise<void>;
    /**
     * Gets the specified dashboard object by its id. If a dashboard object is not found this method returns undefined.
     *
     * @param dashboardObjectId    The id of an object on the dashboard.
     * @returns                    The dashboard object with that id. Returns undefined if the dashboard object is not found.
     * @since 1.7.0 and Tableau 2021.4
     *
     * The following example shows how you can get a dashboard object using its id.
     * <br/>
     *
     * ```
     *   var dashboard = tableau.extensions.dashboardContent.dashboard;
     *   var myDashboardObject = dashboard.getDashboardObjectById(8);
     * ```
     */
    getDashboardObjectById(dashboardObjectId: number): DashboardObject | undefined;
    /**
     * Sets the position and size of one or more floating dashboard objects.
     * Throws an error if the dashboard object is invalid
     *
     * @param DashboardObjectPositionAndSizeUpdateArray    Array of objects containing ID and
     * new position and size for dashboard objects in a dashboard.
     * @returns   Empty promise that resolves when the position and size of the dashboard objects have been changed.
     * @since 1.7.0 and Tableau 2021.4
     *
     * The following example shows how you can update the position and size of multiple (valid, floating) dashboard objects in a dashboard
     * <br/>
     *
     * ```
     *   let dashboardObjectPositionAndSizeUpdateArray = [];
     *   let dashboardObjectPositionAndSizeUpdate1 = {
     *     dashboardObjectID: 1,
     *     x: 0,
     *     y: 0,
     *     width: 50,
     *     height: 50
     *   };
     *   let dashboardObjectPositionAndSizeUpdate2 = {
     *     dashboardObjectID: 2,
     *     x: 75,
     *     y: 75,
     *     width: 60,
     *     height: 60
     *   };
     *   dashboardObjectPositionAndSizeUpdateArray.push(dashboardObjectPositionAndSizeUpdate1, dashboardObjectPositionAndsizeUpdate2);
     *   tableau.extensions.dashboardContent.dashboard.moveAndResizeDashboardObjectsAsync(dashboardObjectPositionAndSizeUpdateArray)
     *   .then(() => {
     *     console.log("done");
     *   });
     */
    moveAndResizeDashboardObjectsAsync(dashboardObjectPositionAndSizeUpdateArray: DashboardObjectPositionAndSizeUpdateArray): Promise<void>;
    /**
     * Replays an animation for the active sheet
     * Throws an error if the replay speed is invalid
     *
     * @param ReplaySpeedType    The replay speed type for the animation (slow, normal, fast).
     * @returns              Empty promise that resolves when the animation has been replayed.
     * @since 1.7.0 and Tableau 2021.4
     *
     * The following example shows how you can replay an animation in a dashboard.
     * <br/>
     *
     * ```
     *   let replaySpeed = tableau.ReplaySpeedType.Normal;
     *   tableau.extensions.dashboardContent.dashboard.replayAnimationAsync(replaySpeed).then(() => {
     *     console.log("done");
     *   });
     */
    replayAnimationAsync(replaySpeed: ReplaySpeedType): Promise<void>;
    /**
     * @returns The collection of filters used on the dashboard
     * @since 1.9.0 and Tableau 2022.2
     */
    getFiltersAsync(): Promise<Array<Filter>>;
    /**
     * Applies a simple categorical filter (non-date) to the dashboard.
     * This method is similar to the method used for worksheets, but applies the filter to all the worksheets in the dashboard that have that same field.
     * Note that the filter is ignored by a worksheet if the worksheet doesn't have the relevant field in its data source.
     *
     * @param fieldName      The name of the field to filter on.
     * @param values         The list of values to filter on.
     * @param updateType     The update type of this filter (add, all, remove, replace).
     * @param filterOptions  Advanced filter options (isExcludeMode).
     *
     * @returns  The field name that the filter is applied on.
     * @since 1.9.0 and Tableau 2022.2
     */
    applyFilterAsync(fieldName: string, values: Array<string>, updateType: FilterUpdateType, filterOptions: FilterOptions): Promise<string>;
}
/**
 * Map object that can be passed into setZoneVisibilityAsync.
 * @deprecated
 * @category Dashboard Extensions
 */
export declare type ZoneVisibilityMap = Map<number, ZoneVisibilityType> | object;
/**
 * Map object that can be passed into setDashboardObjectVisibilityAsync.
 * @category Dashboard Extensions
 */
export declare type DashboardObjectVisibilityMap = Map<number, DashboardObjectVisibilityType>;
/**
 * Array object that can be passed into moveAndResizeDashboardObjects.
 * @category Dashboard Extensions
 */
export declare type DashboardObjectPositionAndSizeUpdateArray = Array<DashboardObjectPositionAndSizeUpdate>;
/**
 * An object to specify a dashboard object and its new position and size in a dashboard.
 * @category Dashboard Extensions
 */
export interface DashboardObjectPositionAndSizeUpdate {
    /**
     * @returns  dashboard object ID
     */
    readonly dashboardObjectID: number;
    /**
     * @returns  X coordinate
     */
    readonly x: number;
    /**
     * @returns  Y coordinate
     */
    readonly y: number;
    /**
     * @returns  width
     */
    readonly width: number;
    /**
     * @returns  height
     */
    readonly height: number;
}
/**
 * An object of a dashboard.
 * @category Dashboard Extensions
 */
export interface DashboardObject {
    /**
     * @returns The Dashboard object that contains this object.
     */
    readonly dashboard: Dashboard;
    /**
     * @returns  What the object represents.
     */
    readonly type: DashboardObjectType;
    /**
     * @returns  The coordinates relative to the top-left corner of the dashboard containing this object.
     */
    readonly position: Point;
    /**
     * @returns  The size of the object.
     */
    readonly size: Size;
    /**
     * @returns  If type returns WORKSHEET or QUICKFILTER, this returns a Worksheet object, undefined otherwise.
     */
    readonly worksheet: Worksheet | undefined;
    /**
     * @returns The name of the dashboard object. This is the name given to the object during authoring.
     * @since 1.1.0
     */
    readonly name: string;
    /**
     * @returns True if the object is floating in the dashboard.
     * @since 1.1.0
     */
    readonly isFloating: boolean;
    /**
     * @returns True if the object is visible.
     * @since 1.1.0
     */
    readonly isVisible: boolean;
    /**
     * @returns  The id of the dashboard object
     * @since 1.1.0
     */
    readonly id: number;
    /**
     * @returns  The field id of the dashboard object if it is a QuickFilter
     */
    readonly fieldId: string | undefined;
}
/**
 * Represents an x/y coordinate in pixels.
 */
export interface Point {
    /**
     * @returns  X coordinate of point.
     */
    readonly x: number;
    /**
     * @returns  Y coordinate of point.
     */
    readonly y: number;
}
/**
 * Levels to apply to a hierarchical filter
 * @since Extensions 1.10.0 and Tableau version 2022.3
 */
export interface HierarchicalLevels {
    levels: Array<string>;
}
//# sourceMappingURL=SheetInterfaces.d.ts.map