import { DataType, IncludeDataValuesOption } from './Namespaces/Tableau';
import { MarkInfo } from './SelectionInterfaces';
export interface Column {
    /**
     * @returns  The name of the field in the column. In summary data, this includes the aggregation.
     * The summary data field name is not stable across languages.
     * For example, in an English version of Tableau, the field name might be SUM(Sales). In French, this would be SOMME(Sales).
     */
    readonly fieldName: string;
    /**
     * @returns  The fieldId of the field in the column. In summary data, this includes the aggregation.
     * The fieldId is not stable across replacing data sources.
     * For example after replacing the data source [Clipboard_20210305T164000].[sum:Sales:qk] could become
     * [federated.12usuoq1171o1b1ebdyh60fjnev1].[sum:Sales:qk].
     *
     * @since 1.5.0
     */
    readonly fieldId: string;
    /**
     * @returns The data type of the column. Possible values are
     *           float, integer, string, boolean, date, datetime and spatial
     */
    readonly dataType: DataType;
    /**
     * @returns  Whether the column data is referenced in the visualization.
     */
    readonly isReferenced: boolean;
    /**
     * @returns  The number of rows in the returned data.
     */
    readonly index: number;
}
export interface DataTable {
    /**
     * @returns  Either "Underlying Data Table" or "Summary Data Table".
     */
    readonly name: string;
    /**
     * @returns  A two-dimensional array of data without the sheet or column
     *           metadata. The first array index is the row index and the second
     *           array index is the column index.
     */
    readonly data: Array<Array<DataValue>>;
    /**
     * @returns  An array of information about marks.  Each mark in the array corresponds
     *           to a row in the data of this DataTable. MarkInfo is currently only partially
     *           available within results from getSelectedMarksAsync / getMarksAsync.
     */
    readonly marksInfo?: Array<MarkInfo>;
    /**
     * @returns  The column information, including the name, data type, and index..
     */
    readonly columns: Array<Column>;
    /**
     * @returns  The number of rows in the returned data.
     */
    readonly totalRowCount: number;
    /**
     * @returns True if the rows returned have been limited to the maximum number of retrievable rows.
     *          A value of true indicates that the caller requested more rows than the limit
     *          and the underlying data source contains more rows than can be returned.
     *          isTotalRowCountLimited can be true in the case of ...
     *          `getAllPagesAsync` with more than 4,000,000 rows in the summary or underlying data.
     *          `getLogicalTableDataAsync` or `getUnderlyingTableDataAsync` with more than 10,000 rows in the data.
     *          In all these cases, limits can be avoided by processing the data in page sized chunks with `DataTableReader`.
     *          isTotalRowCountLimited is always false in the results of DataTableReader.getPageAsync().
     */
    readonly isTotalRowCountLimited?: boolean;
    /**
     * @returns  Whether the data is summary data or underlying data.
     *           Returns true for summary data.
     */
    readonly isSummaryData?: boolean;
}
export interface DataValue {
    /**
     * @since 1.2.0 Fixes the type to be the raw native value rather than a string.
     * @returns  Contains the raw native value as a JavaScript type, which is
     *           one of string, number, boolean, or Date (as a string). Please note that special
     *           values, regardless of type, are always returned as a String surrounded by
     *           percent signs, such as '%null%', or '%no-access%'.
     */
    readonly value: any;
    /**
     * @since 1.4.0
     * @returns The raw native value as a JavaScript type, which is
     *          one of string, number, boolean, or Date object. Please note that special
     *          values are returned as null. The actual special value can be found
     *          in formattedValue, which would be something like 'Null', or 'No-Access'.
     *          Using nativeValue can greatly simplify your error checking since all values
     *          will be their native type value or null.
     */
    readonly nativeValue: any;
    /**
     * @returns  The value formatted according to the locale and the
     *           formatting applied to the field or parameter.
     */
    readonly formattedValue?: string;
    /**
     * @returns The alias of a value only if `hasAlias` is true.
     */
    readonly aliasValue?: string;
    /**
     * @returns Indicates if the DataValue contains an alias (for DataValues of Parameters with domain restriction type
     *          `ParameterValueType.List`).
     */
    readonly hasAlias?: boolean;
}
/**
 * Options argument for the Worksheet.GetSummaryDataAsync API
 */
export interface GetSummaryDataOptions {
    /**
     * Do not use aliases specified in the data source in Tableau. Default is false.
     */
    ignoreAliases?: boolean;
    /**
     * Only return data for the currently selected marks. Default is false.
     */
    ignoreSelection?: boolean;
    /**
     * The columns to return specified by field id, returns all by default.
     * Since 1.5.0, fieldId is a property of the Column object.
     *
     * @since 1.5.0
     */
    columnsToIncludeById?: Array<string>;
    /**
     * The number of rows of data that you want to return. A value of `0` will attempt to return all rows.
     * `0` is the default if maxRows is not specified.
     * `getUnderlyingTableDataAsync` - maximum number of rows returned is capped at 10,000 regardless of maxRows.
     * `getSummaryDataAsync` - maximum number of rows returned is not capped, but performance may suffer with large row counts.
     *
     * @since 1.5.0 maxRows is now supported in both `GetSummaryDataOptions` and `GetUnderlyingDataOptions`.
     * @since 1.10.0 maxRows is ignored when getting a DataTableReader
     */
    maxRows?: number;
    /**
     * Specify which properties to return in DataValues. The default is `IncludeDataValuesOption.AllValues`.
     * All properties not requested will be `undefined` in the DataValue results.
     * This is a performance optimization only, and will be ignored in Tableau versions prior to 2021.2.
     *
     * @since 1.5.0
     */
    includeDataValuesOption?: IncludeDataValuesOption;
    /**
     * Specifies whether to apply worksheet level formatting to numbers and dates
     * Note that this is different from the global field formatting degined in the Schema Viewer
     *
     * @since 1.13.0 and Tableau 2025.1
     */
    applyWorksheetFormatting?: boolean;
}
/**
 * Options argument for the Worksheet.getUnderlyingTableDataAsync API.
 */
export interface GetUnderlyingDataOptions extends GetSummaryDataOptions {
    /**
     * Return all the columns for the data source. Default is false.
     */
    includeAllColumns?: boolean;
}
/**
 * A DataTableReader allows iteration over summary or underlying data by pages.
 * The page size is established when the DataTableReader is created.
 * (See getLogicalTableDataReaderAsync, getSummaryDataReaderAsync, or getUnderlyingTableDataReaderAsync.)
 * The normal sequence of operations would be to
 * 1. Create the DataTableReader for the desired DataTable.
 * 2. Use DataTableReader.totalRowCount or DataTableReader.pageCount to discover how many rows or pages are in the desired DataTable.
 * 3. Call DataTableReader.getPageAsync() to get the page(s) desired. Each page is a DataTable for that page.
 *    Alternatively, based on the DataTableReader.totalRowCount, DataTableReader.getAllPagesAsync can be used to fetch the entire DataTable.
 * 4. Call DataTableReader.releaseAsync() to free up resources.
 *
 * Notes for usage of a DataTableReader:
 * 1. Since DataTableReaders consume server resources, an inactive DataTableReader will be automatically
 *    released after 60 minutes of inactivity. (A new DataTableReader can be created at that time, if needed.)
 * 2. Calling getPageAsync() after an explicit or automatic releaseAsync() will throw an exception.
 * 3. Only one active DataTableReader per logical table id is supported.
 * 4. There are still limits on the number of rows supported for underlying and logical data table readers.
 *    The default limit is approximately 1 million rows of data for getUnderlyingTableDataReaderAsync,
 *    and approximately 32 million cells (rows * columns) for getLogicalTableDataReaderAsync.
 *    Administrators may change these limits to better match computing resources with the Tableau Server (Cloud) or Tableau Desktop options:
 *    ExtensionsAndEmbeddingReaderRowLimit for getUnderlyingTableDataReaderAsync or
 *    ExtensionsAndEmbeddingReaderCellLimit for getLogicalTableDataReaderAsync.
 *
 * @since 1.10.0 and Tableau 2022.4
 */
export interface DataTableReader {
    /**
     * @returns  The number of rows in the full data table.
     */
    readonly totalRowCount: number;
    /**
     * @returns  The number of pages in the full data table. The last page could be a partial page.
     */
    readonly pageCount: number;
    /**
     * Get a page of data. The page is returned as a DataTable.
     * Calls to getPageAsync() after releaseAsync() will throw an exception.
     *
     * @param pageNumber  The page number (zero-indexed) to fetch. The page number should be treated
     *                    like an array index with range: 0 <= pageNumber < pageCount.
     * @returns           A DataTable containing the requested page. The number of rows returned
     *                    can be less than the page size at the end of the data.
     *
     * ```
     * const pageRowCount = 200;
     * const dataTableReader = await worksheet.getSummaryDataReaderAsync(pageRowCount, options);
     * for (let currentPage = 0; currentPage < dataTableReader.pageCount; currentPage++) {
     *   const currentPageDataTable = await dataTableReader.getPageAsync(currentPage);
     *   // ... process current page ...
     * }
     * await dataTableReader.releaseAsync();
     * ```
     */
    getPageAsync(pageNumber: number): Promise<DataTable>;
    /**
     * Get all the pages of data into a single DataTable.
     * Calls to getAllPagesAsync() after releaseAsync() will throw an exception.
     * To protect against possible browser failure, getAllPagesAsync will cap the data at a maximum of 400 pages.
     * With a default pageRowCount of 10,000 this will give you a maximum of 4,000,000 rows of data.
     *
     * If sizes are larger than this, please process your data in page size chunks.
     * @param maxRows Limits the request to maxRows. If maxRows === 0, requests all rows.
     * @returns       A DataTable containing all the data available to the DataTableReader with the maximum page count above.
     *
     * ```
     * // To simplify the example, we assume we have less than 4m rows of data
     * // Since we are fetching all of the data, use the default page size in getSummaryDataReaderAsync
     * const dataTableReader = await worksheet.getSummaryDataReaderAsync();
     * const dataTable = await dataTableReader.getAllPagesAsync();
     * await dataTableReader.releaseAsync();
     * // ... process the data table ...
     * ```
     */
    getAllPagesAsync(maxRows?: number): Promise<DataTable>;
    /**
     * Release all resources held by the DataTableReader.
     * Calling this when done with the DataTableReader is required practice as it frees up resources.
     * Calls to getPageAsync() after releaseAsync() will throw an exception.
     */
    releaseAsync(): Promise<void>;
}
//# sourceMappingURL=DataTableInterfaces.d.ts.map